/*
 * Copyright 2005-2006 Myriad Genetics, Inc.
 *
 * All rights reserved.
 */

package com.myriad.tmap;

import java.io.File;
import javax.swing.*;
import com.myriad.tmap.compute.Pedigree;
import com.myriad.tmap.improve.MapComponent;

/** A base class which can provide a building operation, either with or without
    split mother and father recombination rates. It first asks for a pedigree
    file, if that was not provided on the command line. Then it asks for a
    linkage group, again, if that was not provided on the command line. Then it
    builds an initial map of that linkage group. */
class BuilderBase {
    protected static void main(boolean split, String[] argv) {
        FileGetter      getter = new FileGetter();
        Pedigree        ped = getter.getPed(argv.length < 1 ? null : argv[0]);
        String          markerFile;
        String[]        markers;
        WorkingDialog   working;
        MapComponent    mapComp;
        
        markerFile = argv.length < 2 ? getter.getMarkerPath() : argv[1];
        markers = ped.getOrder(markerFile);
        if (markers == null)
            System.exit(1);
        String name = (new File(markerFile)).getName();
        working = new WorkingDialog("Building linkage group " + name + " from "
                    + ped.getFilename());
        ped.build(markers, split);
        working.dispose();
        
        /* :TODO: should pass along the map structure here. */
        mapComp = new MapComponent(ped, markers, split, name);
        mapComp.putInNewFrame(null);
    }
}
