/*
 * Copyright 2005-2006 Myriad Genetics, Inc.
 *
 * All rights reserved.
 */

package com.myriad.tmap;

import com.myriad.tmap.compute.Pedigree;
import javax.swing.*;

/** Functions which will open dialog boxes to select pedigree files or linkage
    group files. Used during initialization by the various main functions */
class FileGetter {
    FileGetter()
    {
        chooser = null;
        ped = null;
    }
    
    /** Reads a pedigree from a file.
        @param path the path to use or null, meaning the function will prompt
        the user for a path using a dialog box. */
    Pedigree getPed(String path)
    {
        if (path == null) {
            int     result;
            
            if (chooser == null)
                chooser = new JFileChooser();
            
            chooser.setDialogTitle("Choose pedigree data file");
            result = chooser.showOpenDialog(null);
            if (result != JFileChooser.APPROVE_OPTION)
                System.exit(0);
            path = chooser.getSelectedFile().getAbsolutePath();
        }
        
        try {
            ped = new Pedigree(path);
        } catch (Exception e) {
            JOptionPane.showMessageDialog(null, "Couldn't read pedigree file",
                                          "Pedigree file error",
                                          JOptionPane. ERROR_MESSAGE);
            System.exit(1);
        }
        return ped;
    }

    String getMarkerPath()
    {
        int     result;
        
        if (chooser == null)
            chooser = new JFileChooser();
        
        chooser.setDialogTitle("Choose linkage group file");
        result = chooser.showOpenDialog(null);
        if (result != JFileChooser.APPROVE_OPTION)
            System.exit(0);
        return chooser.getSelectedFile().getAbsolutePath();
    }
    
    private JFileChooser    chooser;
    private Pedigree        ped;
}
