/*
 * Copyright 2008 Dustin Cartwright
 *
 * All rights reserved.
 */

package com.myriad.tmap;

import javax.swing.JFileChooser;
import com.myriad.tmap.compute.Pedigree;

/** Main class which uses a pedigree file and computes the corrected phases.
    If a pedigree file is not provided on the command line, it prompts the user
    with a dialog box. */
class Phasing {
    public static void main(String[] argv) {
        Pedigree        ped;
        WorkingDialog   working;
        
        if (argv.length > 1) {
            System.err.println("Too many arguments");
            System.exit(1);
        }
        
        ped = (new FileGetter()).getPed(argv.length > 0 ? argv[0] : null);
        working = new WorkingDialog("Phasing " + ped.getFilename());
        Pedigree.Swaps swaps = ped.phasing();
        working.dispose();

        JFileChooser    pedChooser = new JFileChooser();
        pedChooser.setDialogTitle("Save phased pedigree");
        if (pedChooser.showSaveDialog(null) == JFileChooser.APPROVE_OPTION)
            ped.writePed(pedChooser.getSelectedFile());
        
        JFileChooser    phaseChooser = new JFileChooser();
        phaseChooser.setDialogTitle("Save JoinMap file");
        phaseChooser.setCurrentDirectory(pedChooser.getCurrentDirectory());
        if (phaseChooser.showSaveDialog(null) == JFileChooser.APPROVE_OPTION)
            swaps.writeJoinMapFile(phaseChooser.getSelectedFile());
        
        new ContinueToGroupingDialog(ped);
    }
    
}
