/*
 * Copyright 2005-2006 Myriad Genetics, Inc.
 *
 * All rights reserved.
 */

package com.myriad.tmap.grouping;

import java.awt.*;
import java.awt.font.FontRenderContext;
import java.util.ArrayList;

/** Represents a single marker in the linkage group tree. These are the only
    leaf nodes in the tree. */
class Marker extends LinkGroupNode implements Comparable {
    public Marker(String aName)
    {
        name = aName;
    }
    
    /** Compares the object to another Marker object based on their names. This
        allows the objects to be easily sorted by name. */
    public int compareTo(Object o)
    {
        Marker  m = (Marker) o;
        
        return name.compareTo(m.name);
    }
    
    int position(int upperBound, double minLod)
    {
        bottom = upperBound + vertSpacing;
        return bottom;
    }
    
    Point paint(Graphics2D g, DisplayParameters params, int t, int b)
    {
        int     center = bottom - vertSpacing / 2;
        
        setPaintColor(g);
        
        g.drawString(name, params.markerX + stubLen, bottom);
        
        return new Point(params.markerX + stubLen, center);
    }
    
    int getPreferredHeight(double minLod)
    {
        return vertSpacing;
    }

    int getMaxMarkerWidth(Graphics2D g)
    {
        FontRenderContext   frc = g.getFontRenderContext();
        Font                f = g.getFont();
        double              width = f.getStringBounds(name, frc).getWidth();
        
        return ((int) width) + stubLen + margin;
    }
    
    LinkGroupNode findNodeForPoint(Point p, DisplayParameters params)
    {
        /* If the parent is a LinkGroupMerge, this check on the y coordinate
           is redundant, but it is necessary if the parent is a LinkGroupCluster
         */
        if (p.y < bottom && p.y > bottom - vertSpacing)
            return this;
        else
            return null;
    }
    
    Marker findMarkerByName(String aName)
    {
        if (name.equals(aName))
            return this;
        else
            return null;
    }
    
    void setSelected(boolean sel)
    {
        selected = sel;
    }
    
    /** Sets the used status of the marker. This changes how it is displayed.
        Unlinke the selected status, the used status only exists for Marker
        nodes. */
    void setUsed(boolean aUsed)
    {
        used = aUsed;
    }
    
    int getStatus()
    {
        return (selected ? statusSelectedMask : 0)
                | (used ? statusUsedMask : 0);
    }
    
    String getName()
    {
        return name;
    }
    
    int getTop()
    {
        return bottom - vertSpacing;
    }
    
    protected void getMarkerList(ArrayList acc, boolean sel)
    {
        if (!sel || selected)
            acc.add(this);
    }
    
    private String  name;
    private int     bottom;
    private boolean selected;
    private boolean used;
    
        /** The space between markers vertically. */
    private static final int    vertSpacing = 10;
        /** The length of the stub connector to the left of the marker name.
            This is not drawn by this class, but will be drawn by any higher
            node in the tree. */
    private static final int    stubLen = 5;
        /** The amount of extra space on the right beyond the longest marker
            name. */
    private static final int    margin = 5;
}
