/*
 * Copyright 2005-2006 Myriad Genetics, Inc.
 *
 * All rights reserved.
 */

#include "inputOrder.h"
#include "input.h"
#include <stdlib.h>
#include <string.h>
#include <ctype.h>

char *readOrderName(FILE *fp);

/* Creates a map by reading the order from a file. The order file consists of
   a series of lines, each of which begins with a marker name, followed by
   white space. The text after the white space is ignored.
   
   The caller is responsible for calling free on the returned pointer.
 */
marker_t **readOrderFile(pedigree_t *ped, int *numMarks, const char *path)
{
    FILE        *fp = fopen(path, "r");
    marker_t    **res;
    
    if (fp == NULL) {
        fprintf(stderr, "Could not open %s for reading\n", path);
        return FALSE;
    }
    
    res = readOrder(ped, numMarks, fp);
    fclose(fp);
    return res;
}

marker_t **readOrder(pedigree_t *ped, int *numMarks, FILE *fp)
{
    char        *name;
    marker_t    **order;
    
    *numMarks = 0;
    order = (marker_t **)malloc(ped->numMarks * sizeof(marker_t *));
    
    while ((name = readOrderName(fp)) != NULL) {
        int     i;
        int     c;
        
        for (i = 0; i < ped->numMarks; ++i) {
            if (strcmp(ped->markers[i].name, name) == 0) {
                if (*numMarks == ped->numMarks) {
                    fprintf(stderr, "Error: there are more markers in the ");
                    fprintf(stderr, "order than in the pedigree. There must ");
                    fprintf(stderr, "be\nrepeats.\n");
                    free(order);
                    return NULL;
                }
                order[(*numMarks)++] = ped->markers + i;
                break;
            }
        }
            /* When we read in the output, the first line will begin with name,
             * but we don't want to report this as a missing marker. */
        if (i == ped->numMarks && (*numMarks > 0 || strcmp(name, "name") != 0))
            fprintf(stderr, "Couldn't find marker with name %s\n", name);
        
        while ((c = getc(fp)) != EOF && c != '\n')
            ;
    }
    
    if (*numMarks == 0) {
        free(order);
        fprintf(stderr, "Couldn't find any markers\n");
        return NULL;
    }
    
    return (marker_t **)realloc(order, *numMarks * sizeof(marker_t *));
}

/* Reads a name from the stream in the context of reading an order file.
   This method is more tolerant than readName in that it will ignore leading
   white space.
 */
char *readOrderName(FILE *fp)
{
    int     c;

    while(isspace(c = getc(fp)))
        ;
    ungetc(c, fp);
    return readName(fp);
}
