/*
 * Copyright 2005-2006 Myriad Genetics, Inc.
 *
 * All rights reserved.
 */

#ifndef _H_MAP_
#define _H_MAP_

#include "genmap.h"
#include "ped.h"
#include <stdio.h>

/* Represents a map, including the distances and errors.
   
   The elements recombsMoth and recombsFath may point to the same memory region
   which means that the two recombination fractions are fixed as equal. The same
   thing is true for errorsMoth and errorsFath.
 */
typedef struct {
    pedigree_t  *ped;
    int         numMarks;
    marker_t    **order;        /* length numMarks */
    prob_t      *recombsMoth;   /* length numMarks - 1 */
    prob_t      *recombsFath;   /* length numMarks - 1 */
    prob_t      *errorsMoth;    /* length numMarks */
    prob_t      *errorsFath;    /* length numMarks */
    prob_t      logLlhd;        /* log 10 of the likelihood */
} map_t;

void allocMap(map_t *, pedigree_t *, int numMarks, int separateParents);
void allocSimilarMap(map_t *, const map_t *model);
void freeMap(map_t *);

void copyMap(map_t *, const map_t *);
void swapMaps(map_t *, map_t *);

prob_t theta2Dist(prob_t theta);
prob_t theta2DistHaldane(prob_t theta);
prob_t theta2DistKosambi(prob_t theta);

prob_t distKosambi2Theta(prob_t dist);
prob_t dist2Theta(prob_t dist);

void printMap(FILE *, map_t *);

void normalizeMap(map_t *);
void normalizeMapDists(map_t *);

#endif
